# BiomechZoo for Python
This is a development version of the biomechzoo toolbox for python. 

## How to install 
- biomechZoo for python is now an official package, you can simply add biomechZoo to your environment using
``pip install biomechzoo``

## Usage notes
- If you need to install a specific version, run ``pip install biomechzoo==x.x.x`` where x.x.x is the version number. 
- If you need to update biomechzoo to the latest version in your env, run ``pip install biomechzoo --upgrade``

See also http://www.github.com/mcgillmotionlab/biomechzoo or http://www.biomechzoo.com for more information